compute_rows_per_band

Function compute_rows_per_band 

pub const fn compute_rows_per_band(
    signature_size: usize,
    num_bands: usize,
) -> Option<usize>
Compute the number of rows per band given signature size and num bands.

Returns None if the signature size is not evenly divisible by num bands.