pub const fn compute_rows_per_band(
signature_size: usize,
num_bands: usize,
) -> Option<usize>Expand description
Compute the number of rows per band given signature size and num bands.
Returns None if the signature size is not evenly divisible by num bands.