pub struct StatefulDedupTransform { /* private fields */ }Expand description
A stateful deduplication transform that buffers samples.
This is the recommended transform for deduplication as it properly handles the stateful nature of duplicate detection.
Implementations
Sourceimpl StatefulDedupTransform
impl StatefulDedupTransform
Sourcepub fn new(config: Config) -> Result<Self>
pub fn new(config: Config) -> Result<Self>
Create a new stateful deduplication transform.
Errors
Returns an error if the configuration is invalid.
Sourcepub fn with_text_field(self, field: impl Into<String>) -> Self
pub fn with_text_field(self, field: impl Into<String>) -> Self
Set the text field name.
Sourcepub fn with_mark_duplicates(self, enabled: bool) -> Self
pub fn with_mark_duplicates(self, enabled: bool) -> Self
Enable marking duplicates.
Sourcepub fn clusters(&mut self) -> &[DuplicateCluster]
pub fn clusters(&mut self) -> &[DuplicateCluster]
Get duplicate clusters.